@@ -978,6 +978,8 @@ baum_brl_input_parser (gint new_val)
 
 gint 
 baum_brl_send_dots (guchar *dots,
+		    gchar* text,
+		    gshort cursor_position,
 		    gshort count,
 		    gshort blocking)
 {
