@@ -86,6 +86,8 @@ typedef struct
 
 typedef void  (* BRLDevCloseDeviceProc) ();
 typedef gint  (* BRLDevSendDotsProc)    (guchar *dots,
+					 gchar *text,
+					 gshort cursorPosition,
 				        gshort length,
 				        gshort blocking);
 
@@ -126,7 +128,7 @@ void   brl_terminate   ();
 
 /* DEVICE LEVEL */
 gint   brl_open_device   (gchar       *device_name, 
-		         gint         port,
+		         gchar         *port,
 		         BRLEventProc braille_event_proc);	
 gint   brl_get_device    (BRLDevice   *device);
 void   brl_close_device  ();
@@ -138,6 +140,7 @@ gshort brl_get_display_width (gshort      display);
 void   brl_set_dots          (gshort      display, 
 			     gshort       start_cell,
 			     guchar       *new_dots,
+			     guchar 	  *new_text,
 			     gshort       cell_count,
 			     gshort 	  offset,
 			     gshort       cursor_position);
