@@ -1,7 +1,7 @@
 /* brlxmlapi.h
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -28,7 +28,7 @@ typedef void (*BRLXmlInputProc) (gchar *buffer,
 				 gint   len);
 
 gint  brl_xml_init     (gchar          *device_name,
-		       gint            port,
+		       gchar           *port,
 		       BRLXmlInputProc input_callback_proc);
 void brl_xml_terminate (void);
 void brl_xml_output    (gchar          *buffer,
