@@ -770,6 +770,8 @@ handy_brl_input_parser (gint new_val)
 /* sends line to braille device */
 gint
 handy_brl_send_dots (guchar *dots, 
+		     gchar *text,
+		     gshort cursor_position,
 		     gshort count, 
 		     gshort blocking)
 {
