@@ -1,7 +1,7 @@
 /* coreconf.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -485,7 +485,7 @@ srcore_changes_cb (GConfClient	*client,
     gchar *key = NULL;
     
     sru_return_if_fail (entry);
-    if (!entry->value)
+    if (!entry->value || !general_setting)
 	return;
     
     key = (gchar*) gconf_entry_get_key (entry);
