@@ -493,3 +493,17 @@ gn_load_io_settings (void)
     return TRUE;
 }
 
+void
+gn_move_to_display (const gchar *display)
+{
+    GdkDisplay *disp;
+
+    disp = gdk_display_open (display);
+    if (disp)
+	gdk_display_manager_set_default_display (gdk_display_manager_get (), disp);
+
+    if (!w_gnopernicus)
+	return;
+
+    gtk_window_set_screen (GTK_WINDOW (w_gnopernicus), gdk_screen_get_default ());
+}
