@@ -32,6 +32,18 @@
 #define MAGUI_ALIGNMENT_MIN		"min"
 #define MAGUI_ALIGNMENT_MAX		"max"
 
+#define VAL8_TO_16(X)		(((X) << 8) + (X))
+#define VAL16_TO_8(X)		((X) & 0xff)
+#define COLOR(a, r, g, b) 	((VAL16_TO_8 (b)) | \
+				((VAL16_TO_8 (g)) << 8) | \
+				((VAL16_TO_8 (r)) << 16) | \
+				((VAL16_TO_8 (a)) << 24))
+
+#define COLOR_ALPHA(c)		(VAL8_TO_16 (((c) >> 24) & 0xff))
+#define COLOR_RED(c)		(VAL8_TO_16 (((c) >> 16) & 0xff))
+#define COLOR_GREEN(c)		(VAL8_TO_16 (((c) >>  8) & 0xff))
+#define COLOR_BLUE(c)		(VAL8_TO_16 (((c)      ) & 0xff))
+
 enum {
     MAG_FOCUS_TRACKING_NONE = 0,
     MAG_FOCUS_TRACKING_CENTERED,
@@ -119,9 +131,9 @@ GtkWidget    	*sp_zp_left,
 		*sp_zp_top,
 		*sp_zp_width,
 		*sp_zp_height;
-GtkWidget	*cp_border_color,
-		*cp_crosswire_color,
-		*cp_cursor_color;
+GtkWidget	*cb_border_color,
+		*cb_crosswire_color,
+		*cb_cursor_color;
 GtkWidget	*rb_focus_tracking[MAG_FOCUS_TRACKING_NUMBER];
 
 static void 
@@ -131,7 +143,7 @@ magui_cursor_off (gboolean val)
     gboolean crosswire_clip = val;
 	
     gtk_widget_set_sensitive ( GTK_WIDGET (ck_cursor_mag), val);
-    gtk_widget_set_sensitive ( GTK_WIDGET (cp_cursor_color), val);
+    gtk_widget_set_sensitive ( GTK_WIDGET (cb_cursor_color), val);
     gtk_widget_set_sensitive ( GTK_WIDGET (lb_cursor_color), val);
     
     if (val)
@@ -159,7 +171,7 @@ magui_crosswire_off (gboolean val)
 	
     gtk_widget_set_sensitive ( GTK_WIDGET (ck_crosswire_clip), val);
     gtk_widget_set_sensitive ( GTK_WIDGET (sp_crosswire_size), val);
-    gtk_widget_set_sensitive ( GTK_WIDGET (cp_crosswire_color), val);
+    gtk_widget_set_sensitive ( GTK_WIDGET (cb_crosswire_color), val);
     gtk_widget_set_sensitive ( GTK_WIDGET (lb_crosswire_size), val);
     gtk_widget_set_sensitive ( GTK_WIDGET (lb_crosswire_color), val);
     gtk_widget_set_sensitive ( GTK_WIDGET (ck_crosswire_color_invert), val);    
@@ -173,7 +185,7 @@ magui_crosswire_off (gboolean val)
 static void
 magui_crosswire_color_invert_off (gboolean val)
 {
-    gtk_widget_set_sensitive ( GTK_WIDGET (cp_crosswire_color), val);
+    gtk_widget_set_sensitive ( GTK_WIDGET (cb_crosswire_color), val);
     gtk_widget_set_sensitive ( GTK_WIDGET (lb_crosswire_color), val);   
 }
 
@@ -386,15 +398,14 @@ magui_cursor_color_color_set(GtkWidget *w,
 			    guint a,
 			    gpointer data)
 {
-    guint8 r8,g8,b8,a8;
+    GdkColor color;
+    guint16 a16;
     guint ret_color = 0;
-    gnome_color_picker_get_i8   (GNOME_COLOR_PICKER (cp_cursor_color), 
-				    &r8, &g8, &b8, &a8);
 
-    ret_color = 0xff - a8;
-    ret_color = (ret_color << 8) + r8;
-    ret_color = (ret_color << 8) + g8;
-    ret_color = (ret_color << 8) + b8;
+    gtk_color_button_get_color (GTK_COLOR_BUTTON (cb_cursor_color), &color);
+    a16 = gtk_color_button_get_alpha (GTK_COLOR_BUTTON (cb_cursor_color));
+    
+    ret_color = COLOR (a16, color.red, color.green, color.blue);
     
     if (magnifier_setting->cursor_color != ret_color)
     {
@@ -414,16 +425,15 @@ magui_crosswire_color_color_set (GtkWidget *w,
 				guint a,
 				gpointer data)
 {
-    guint8 r8,g8,b8,a8;
+    GdkColor color;
+    guint16 a16;
     guint ret_color = 0;
-    gnome_color_picker_get_i8   (GNOME_COLOR_PICKER (cp_crosswire_color), 
-				    &r8, &g8, &b8, &a8);
 
-    ret_color = 0xff - a8;
-    ret_color = (ret_color << 8) + r8;
-    ret_color = (ret_color << 8) + g8;
-    ret_color = (ret_color << 8) + b8;
+    gtk_color_button_get_color (GTK_COLOR_BUTTON (cb_crosswire_color), &color);
+    a16 = gtk_color_button_get_alpha (GTK_COLOR_BUTTON (cb_crosswire_color));
     
+    ret_color = COLOR (a16, color.red, color.green, color.blue);
+
     if (magnifier_setting->crosswire_color != ret_color)
     {
 	if (ret_color == 0)
@@ -498,26 +508,26 @@ void
 magui_crosswire_color_invert_toggled (GtkWidget *widget,
 				    gpointer data)
 {
-    guint8 r,g,b,a; 
+    GdkColor color;
+    guint16 a16;
     gboolean bval = 
 	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_crosswire_color_invert)); 	    
     
     if (bval)
     {
-	gnome_color_picker_get_i8   (GNOME_COLOR_PICKER (cp_crosswire_color), 
-				    &r, &g, &b, &a);
-				    
-	crosswire_color_old = 0xff - a;
-	crosswire_color_old = (crosswire_color_old << 8) + r;
-	crosswire_color_old = (crosswire_color_old << 8) + g;
-	crosswire_color_old = (crosswire_color_old << 8) + b;
+	gtk_color_button_get_color (GTK_COLOR_BUTTON (cb_crosswire_color), &color);
+	a16 = gtk_color_button_get_alpha (GTK_COLOR_BUTTON (cb_crosswire_color));
+	
+	crosswire_color_old = COLOR (a16, color.red, color.green, color.blue);
 
 	if ( crosswire_color_old != 0 )
 	{
-	    r = g = b = 0;    
-	    a = 0xff;
-	    gnome_color_picker_set_i8 ( GNOME_COLOR_PICKER (cp_crosswire_color), 
-					r, g, b, a);
+	    color.red = color.green = color.green = 0;
+	    a16 = 0xffff;
+	    
+	    gtk_color_button_set_color (GTK_COLOR_BUTTON (cb_crosswire_color), &color);
+	    gtk_color_button_set_alpha (GTK_COLOR_BUTTON (cb_crosswire_color), a16);
+
 	    magnifier_setting->crosswire_color = 0;
 	    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
 					GCONF_VALUE_INT,
@@ -532,20 +542,22 @@ magui_crosswire_color_invert_toggled (GtkWidget *widget,
     }
     else
     {
-	gnome_color_picker_get_i8   (GNOME_COLOR_PICKER (cp_crosswire_color), 
-				    &r, &g, &b, &a);
-				    
-	if ( (r == 0) && (g == 0) && (b == 0) && (0xff - a == 0))
+	
+	gtk_color_button_get_color (GTK_COLOR_BUTTON (cb_crosswire_color), &color);
+	a16 = gtk_color_button_get_alpha (GTK_COLOR_BUTTON (cb_crosswire_color));
+    
+	if ( (color.red == 0) && (color.green == 0) && (color.blue == 0) && (a16 == 0))
 	{
 	    crosswire_color_old = magconf_get_color_old (DEFAULT_MAGNIFIER_SCHEMA,
 							MAGNIFIER_CROSSWIRE_COLOR_INVERT);
-	    b = crosswire_color_old & 0xff;
-	    g = (crosswire_color_old >> 8) & 0xff;
-	    r = (crosswire_color_old >> 16) & 0xff;
-	    a = 0xff - ((crosswire_color_old >> 24) & 0xff);
-
-	    gnome_color_picker_set_i8 ( GNOME_COLOR_PICKER (cp_crosswire_color), 
-					r, g, b, a);
+	    
+	    color.red = COLOR_RED (crosswire_color_old);	    
+	    color.green = COLOR_GREEN (crosswire_color_old);	    
+	    color.blue = COLOR_BLUE (crosswire_color_old);	    
+	    
+	    gtk_color_button_set_color (GTK_COLOR_BUTTON (cb_crosswire_color), &color);
+	    gtk_color_button_set_alpha (GTK_COLOR_BUTTON (cb_crosswire_color), 
+					COLOR_ALPHA (crosswire_color_old));
 					
 	    magnifier_setting->crosswire_color = crosswire_color_old;
 	    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
@@ -604,13 +616,13 @@ magui_set_handlers_magnifier_settings (GladeXML *xml)
     
     ck_cursor_on_off 	= glade_xml_get_widget (xml, "ck_cursor_on_off");
     ck_cursor_mag 	= glade_xml_get_widget (xml, "ck_cursor_magnification");
-    cp_cursor_color 	= glade_xml_get_widget (xml, "cp_cursor_color");
+    cb_cursor_color 	= glade_xml_get_widget (xml, "cb_cursor_color");
     sp_cursor_size 	= glade_xml_get_widget (xml, "sp_cursor_size");
     
     ck_crosswire_clip	= glade_xml_get_widget (xml, "ck_crosswire_clip");
     ck_crosswire 	= glade_xml_get_widget (xml, "ck_crosswire");
     sp_crosswire_size 	= glade_xml_get_widget (xml, "sp_crosswire_size");
-    cp_crosswire_color 	= glade_xml_get_widget (xml, "cp_crosswire_color");
+    cb_crosswire_color 	= glade_xml_get_widget (xml, "cb_crosswire_color");
     ck_crosswire_color_invert = glade_xml_get_widget (xml, "ck_crosswire_color_invert");
 
     lb_cursor_size	= glade_xml_get_widget (xml, "lb_cursor_size");
@@ -644,7 +656,7 @@ magui_set_handlers_magnifier_settings (GladeXML *xml)
 			    GTK_SIGNAL_FUNC (magui_cursor_magnification_toggled));
     glade_xml_signal_connect (xml, "on_sp_cursor_size_value_changed",		
 			    GTK_SIGNAL_FUNC (magui_cursor_size_value_changed));
-    glade_xml_signal_connect(xml,"on_cp_cursor_color_color_set",		
+    glade_xml_signal_connect(xml,"on_cb_cursor_color_color_set",		
 			    GTK_SIGNAL_FUNC(magui_cursor_color_color_set));
 
 				
@@ -656,7 +668,7 @@ magui_set_handlers_magnifier_settings (GladeXML *xml)
 			    GTK_SIGNAL_FUNC (magui_crosswire_clip_toggled));
     glade_xml_signal_connect (xml, "on_sp_crosswire_size_value_changed",		
 			    GTK_SIGNAL_FUNC (magui_crosswire_size_value_changed));
-    glade_xml_signal_connect(xml,"on_cp_crosswire_color_color_set",		
+    glade_xml_signal_connect(xml,"on_cb_crosswire_color_color_set",		
 			    GTK_SIGNAL_FUNC(magui_crosswire_color_color_set));
     
     model 	= magui_create_model ();
@@ -764,28 +776,27 @@ magui_set_crosswire_size (Magnifier *magnifier_setting)
 gboolean
 magui_set_crosswire_color (Magnifier *magnifier_setting)
 {
-    guint8 r,g,b,a; 
+    GdkColor color;
     
     sru_return_val_if_fail (magnifier_setting, FALSE);
     if (!w_magnifier_settings) 
 	return FALSE;
         
-    
-    b = magnifier_setting->crosswire_color & 0xff;
-    g = (magnifier_setting->crosswire_color >> 8) & 0xff;
-    r = (magnifier_setting->crosswire_color >> 16) & 0xff;
-    a = 0xff - ((magnifier_setting->crosswire_color >> 24) & 0xff);
-    
-    gnome_color_picker_set_i8 ( GNOME_COLOR_PICKER (cp_crosswire_color), 
-				r, g, b, a);
+    color.red = COLOR_RED (magnifier_setting->crosswire_color);
+    color.green = COLOR_GREEN (magnifier_setting->crosswire_color);
+    color.blue = COLOR_BLUE (magnifier_setting->crosswire_color);
 
+    gtk_color_button_set_color (GTK_COLOR_BUTTON (cb_crosswire_color), &color);
+    gtk_color_button_set_alpha (GTK_COLOR_BUTTON (cb_crosswire_color), 
+				COLOR_ALPHA (magnifier_setting->crosswire_color));
+    
     if (!magnifier_setting->crosswire_color)
     {
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON 
 				     (ck_crosswire_color_invert),
 				     TRUE); 
 	gtk_widget_set_sensitive     (GTK_WIDGET
-				      (cp_crosswire_color),
+				      (cb_crosswire_color),
 				      FALSE);				     
     }
     else
@@ -842,19 +853,19 @@ magui_set_cursor_size (Magnifier *magnifier_setting)
 gboolean
 magui_set_cursor_color (Magnifier *magnifier_setting)
 {
-    guint8 r,g,b,a; 
+    GdkColor color;
     
     sru_return_val_if_fail (magnifier_setting, FALSE);
     if (!w_magnifier_settings) 
 	return FALSE;
 
-    b = magnifier_setting->cursor_color & 0xff;
-    g = (magnifier_setting->cursor_color >> 8) & 0xff;
-    r = (magnifier_setting->cursor_color >> 16) & 0xff;
-    a = 0xff - ((magnifier_setting->cursor_color >> 24) & 0xff);
-    
-    gnome_color_picker_set_i8 ( GNOME_COLOR_PICKER (cp_cursor_color), 
-				r, g, b, a);
+    color.red = COLOR_RED (magnifier_setting->cursor_color);
+    color.green = COLOR_GREEN (magnifier_setting->cursor_color);
+    color.blue = COLOR_BLUE (magnifier_setting->cursor_color);
+
+    gtk_color_button_set_color (GTK_COLOR_BUTTON (cb_cursor_color), &color);
+    gtk_color_button_set_alpha (GTK_COLOR_BUTTON (cb_cursor_color), 
+				COLOR_ALPHA (magnifier_setting->cursor_color));
 
     return TRUE;
 }
@@ -1069,15 +1080,14 @@ magui_set_target_screen ()
 static void
 magui_set_border_color_value ()
 {
-    guint8 r8,g8,b8,a8;
+    guint16 a16;
+    GdkColor color;
     guint ret_color = 0;
-    gnome_color_picker_get_i8   (GNOME_COLOR_PICKER (cp_border_color), 
-				    &r8, &g8, &b8, &a8);
+    
+    gtk_color_button_get_color (GTK_COLOR_BUTTON (cb_border_color), &color);
+    a16 = gtk_color_button_get_alpha (GTK_COLOR_BUTTON (cb_border_color));
 
-    ret_color = 0xff - a8;
-    ret_color = (ret_color << 8) + r8;
-    ret_color = (ret_color << 8) + g8;
-    ret_color = (ret_color << 8) + b8;
+    ret_color = COLOR (a16, color.red, color.green, color.blue);
     
     if (magnifier_setting->border_color != ret_color)
     {
@@ -1567,7 +1577,7 @@ magui_set_handlers_magnification_options(GladeXML *xml)
 {    
     w_magnification_options 	= glade_xml_get_widget (xml, "w_mag_option");
     sp_border_size 		= glade_xml_get_widget (xml, "sp_border_size");
-    cp_border_color		= glade_xml_get_widget (xml, "cp_border_color");
+    cb_border_color		= glade_xml_get_widget (xml, "cb_border_color");
 
     ck_invert 		= glade_xml_get_widget (xml, "ck_invert");
     ck_panning 		= glade_xml_get_widget (xml, "ck_panning");
@@ -1673,18 +1683,20 @@ magui_set_border_size (Magnifier *magnifier_setting)
 gboolean
 magui_set_border_color (Magnifier *magnifier_setting)
 {
-    guint8 r,g,b,a; 
+    GdkColor color;
+
     sru_return_val_if_fail (magnifier_setting, FALSE);
     if (!w_magnification_options) 
 	return FALSE;
-    
-    b = (magnifier_setting->border_color & 0xff);
-    g = (magnifier_setting->border_color >> 8) & 0xff;
-    r = (magnifier_setting->border_color >> 16) & 0xff;
-    a = 0xff - ((magnifier_setting->border_color >> 24) & 0xff);
 
-    gnome_color_picker_set_i8 ( GNOME_COLOR_PICKER (cp_border_color), 
-				r, g, b, a);
+    color.red = COLOR_RED (magnifier_setting->border_color);    
+    color.green = COLOR_GREEN (magnifier_setting->border_color);    
+    color.blue = COLOR_BLUE (magnifier_setting->border_color);    
+    
+    gtk_color_button_set_color (GTK_COLOR_BUTTON (cb_border_color), &color);
+    gtk_color_button_set_alpha (GTK_COLOR_BUTTON (cb_border_color), 
+				COLOR_ALPHA (magnifier_setting->border_color));
+
     return TRUE;
 }
 
