@@ -85,7 +85,9 @@ int      	crosswire_size  = 0    ;/*thickness of crosswire cursor*/
 guint32		crosswire_color = 0    ;/*color as AlphaRedGreenBlue*/
 gboolean	crosswire_clip  = FALSE;/*whenever to insert the cursor over the crosswire or not*/
 
-MagRectangle display_size;
+MagRectangle source_display_size;
+MagRectangle target_display_size;
+
 MagRectangle source_rect;
 static MagRectangle rect;
 static MagRectangle mouse_tracked_roi;
@@ -93,6 +95,58 @@ static MagRectangle mouse_tracked_roi;
 static MagRectangle roi_viewport;
 extern MagRectangle zp_rect;
 
+static void
+set_boundary (const gchar *disp,
+	     MagRectangle *rect)
+{
+    GdkDisplay *display;
+    GdkScreen *screen;
+    const gchar *start;
+
+    g_assert (disp && rect);
+
+    display = gdk_display_open (disp);
+    if (!display)
+	return;
+
+    for (start = disp; *start && *start != '.'; start++);
+    g_assert (*start);
+    start++;
+    
+    screen = gdk_display_get_screen (display, atoi (start));
+    if (!screen)
+	return;
+
+    rect->left = rect->top = 0;
+    rect->width = gdk_screen_get_width (screen) - 1;
+    rect->height = gdk_screen_get_height (screen) - 1;
+}
+
+
+
+static void
+set_source_boundary (const gchar *source)
+{
+    set_boundary (source, &source_display_size);
+}
+
+static void
+set_target_boundary (const gchar *target)
+{
+    set_boundary (target, &target_display_size);
+    srconf_set_data (MAGNIFIER_DISPLAY_SIZE_X, 
+			 CFGT_INT, 
+			 (gpointer)&target_display_size.width, 
+			 MAGNIFIER_CONFIG_PATH);
+	
+
+    srconf_set_data (MAGNIFIER_DISPLAY_SIZE_Y, 
+			 CFGT_INT, 
+			 (gpointer)&target_display_size.height, 
+			  MAGNIFIER_CONFIG_PATH);
+}
+
+
 /*__DEBUG FUNCION*/
 void 
 mag_zoomer_content(MagZoomer *mag_zoomer)
@@ -288,6 +342,7 @@ mag_zoomer_set_source (MagZoomer *mag_zoomer,
 
 	magnifier_set_source_screen (magnifier, 
 			    	     mag_zoomer->source);
+	set_source_boundary (source);
 }
 
 void 
@@ -303,6 +358,7 @@ mag_zoomer_set_target (MagZoomer *mag_zoomer,
 
 	magnifier_set_target_screen (magnifier, 
 			    	     mag_zoomer->target);
+	set_target_boundary (target);
 }
 
 /* __ MAG ZOOMER PARAMS METHODS ________________________________________________*/
@@ -653,10 +709,10 @@ mag_zoomer_set_ZP_extents_left (MagZoomer *mag_zoomer,
     
     zoom_factor_changed = TRUE;
     
-    if ( zp_left > display_size.left)
+    if ( zp_left > target_display_size.left)
 	(mag_zoomer->zoomer_placement).extents.left = zp_left;
     else
-	(mag_zoomer->zoomer_placement).extents.left = display_size.left;    
+	(mag_zoomer->zoomer_placement).extents.left = target_display_size.left;    
 
     /* get_source has to be called every time set_target is called , 
     because the source changes*/			 
@@ -687,10 +743,10 @@ void mag_zoomer_set_ZP_extents_top (MagZoomer *mag_zoomer,
     
     zoom_factor_changed = TRUE;
 
-    if ( zp_top > display_size.top)
+    if ( zp_top > target_display_size.top)
 	mag_zoomer->zoomer_placement.extents.top = zp_top;
     else
-	mag_zoomer->zoomer_placement.extents.top = display_size.top;    
+	mag_zoomer->zoomer_placement.extents.top = target_display_size.top;    
 
 			 
     magnifier_get_source (magnifier,
@@ -721,10 +777,10 @@ mag_zoomer_set_ZP_extents_width (MagZoomer *mag_zoomer,
 
     zoom_factor_changed = TRUE;
 
-    if ( zp_width < display_size.width)
+    if ( zp_width < target_display_size.width)
         mag_zoomer->zoomer_placement.extents.width = zp_width;
     else
-        mag_zoomer->zoomer_placement.extents.width = display_size.width;	
+        mag_zoomer->zoomer_placement.extents.width = target_display_size.width;	
 
     magnifier_get_source (magnifier,
 			      &source_rect);
@@ -754,10 +810,10 @@ mag_zoomer_set_ZP_extents_height (MagZoomer *mag_zoomer,
     
     zoom_factor_changed = TRUE;
     	
-    if ( zp_height < display_size.height)
+    if ( zp_height < target_display_size.height)
         mag_zoomer->zoomer_placement.extents.height = zp_height;
     else
-        mag_zoomer->zoomer_placement.extents.height = display_size.height;	    
+        mag_zoomer->zoomer_placement.extents.height = target_display_size.height;	    
 
     
     magnifier_get_source (magnifier,
@@ -1526,21 +1582,6 @@ mag_initialize (MagEventCB mag_event)
 			 target_rect.width,
 			 target_rect.height);
 #endif
-	display_size.left = display_size.top = DEFAULT_SCREEN_MIN_SIZE;
-	display_size.width = gdk_screen_width () - 1;
-	display_size.height = gdk_screen_height () - 1;
-	
-        srconf_set_data (MAGNIFIER_DISPLAY_SIZE_X, 
-			 CFGT_INT, 
-			 (gpointer)&display_size.width, 
-			 MAGNIFIER_CONFIG_PATH);
-	
-
-        srconf_set_data (MAGNIFIER_DISPLAY_SIZE_Y, 
-			 CFGT_INT, 
-			 (gpointer)&display_size.height, 
-			  MAGNIFIER_CONFIG_PATH);
-
 /*vertical split*/
 	 rect.top =  target_rect.top;
 	 rect.left = (target_rect.width- target_rect.left) / 2;
