@@ -28,9 +28,6 @@
 static CORBA_Environment ev;
 MagRectangle zp_rect;
 
-gchar *source_display = NULL;
-gchar *target_display = NULL;
-
 static gboolean
 check_return_value (CORBA_Environment 	*env, 
 		    int 		line)
@@ -78,9 +75,6 @@ get_magnifier (void)
 	oclient = CORBA_OBJECT_NIL;
     }
 
-    source_display = NULL;
-    target_display = NULL;    
-    
     return (GNOME_Magnifier_Magnifier) oclient;
 }
 
@@ -97,8 +91,6 @@ magnifier_exit (GNOME_Magnifier_Magnifier	magnifier)
 */	GNOME_Magnifier_Magnifier_dispose (magnifier, &ev);
 	check_return_value (&ev, __LINE__);
     }
-    g_free (source_display);
-    g_free (target_display);
 }
 
 /*________________________SOURCE/TARGET____________________________________*/
@@ -106,8 +98,6 @@ void
 magnifier_set_source_screen (GNOME_Magnifier_Magnifier 	magnifier,
 			     gchar 			*source_display_screen)
 {
-    g_free (source_display);
-    source_display = g_strdup (source_display_screen);
     if (magnifier != CORBA_OBJECT_NIL)
     {
 	GNOME_Magnifier_Magnifier__set_SourceDisplay (magnifier,
@@ -121,8 +111,6 @@ void
 magnifier_set_target_screen (GNOME_Magnifier_Magnifier 	magnifier,
 			     gchar 			*target_display_screen)
 {
-    g_free (target_display);
-    target_display = g_strdup (target_display_screen);
     if (magnifier != CORBA_OBJECT_NIL)
     {
 	    GNOME_Magnifier_Magnifier__set_TargetDisplay (magnifier,
@@ -433,50 +421,6 @@ magnifier_set_crosswire_clip (GNOME_Magnifier_Magnifier 	magnifier,
 
 /*_____________________________ZOOMER PROPERTIES____________________________________*/
 
-static MagRectangle *
-mag_rect_clip_to_source (MagRectangle *roi)
-{    
-    static MagRectangle temp;
-    
-    g_assert (source_display);
-    g_assert (target_display);
-    
-    if (strcmp (source_display, target_display) == 0)
-    {
-	if ((roi->width > zp_rect.left) && (roi->width < zp_rect.width))
-	{
-	    if ((roi->top < zp_rect.height) && (roi->height > zp_rect.top))
-	    {
-		temp.width = zp_rect.left;
-		temp.top = roi->top;
-		temp.left = roi->left - (roi->width - zp_rect.left);
-		temp.height = roi->height;
-	    }
-	else
-	    return roi;    
-	}
-	else
-	    if ((roi->left < zp_rect.width) && (roi->left > zp_rect.left))
-	    {
-		if ((roi->top < zp_rect.height) && (roi->height > zp_rect.top))
-		{
-		    temp.width = (zp_rect.width - roi->left) + roi->width;
-		    temp.top = roi->top;
-		    temp.left = zp_rect.width;
-		    temp.height = roi->height;
-		}
-    		else
-		    return roi;    
-	    }
-	    else 
-		return roi;
-	return &temp;
-    }
-    else
-	return roi;
-}
-
-
 void
 magnifier_set_roi (GNOME_Magnifier_Magnifier 	magnifier,
 		   int 				zoom_region,
@@ -485,8 +429,6 @@ magnifier_set_roi (GNOME_Magnifier_Magnifier 	magnifier,
     GNOME_Magnifier_ZoomRegionList 	*regions;
     
     
-    roi = mag_rect_clip_to_source (roi);
-
     if (magnifier != CORBA_OBJECT_NIL)
     {
 	regions = GNOME_Magnifier_Magnifier_getZoomRegions (magnifier,
