@@ -72,17 +72,17 @@ mag_startElement (void           *ctx,
 	switch (current_state)
 	{
     		case MPS_IDLE:
-			if (g_strcasecmp (name, "MAGOUT") == 0)
+			if (g_strcasecmp ((gchar*)name, "MAGOUT") == 0)
 			{
 				if (attrs)
 				{	
 					while (*attrs)
 					{
-						if (g_strcasecmp (*attrs, "clear") == 0)
+						if (g_strcasecmp ((gchar*)*attrs, "clear") == 0)
 						{
 							++attrs;				
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val); /* trim the attr value*/
 
 							clear = mag_zoomers_clear (tattr_val);
@@ -91,11 +91,11 @@ mag_startElement (void           *ctx,
 							attr_val = NULL;
 						}
 						
-						else if (g_strcasecmp(*attrs, "CursorName") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "CursorName") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);	
 
 							mag_zoomers_set_cursor (tattr_val, NULL, NULL);
@@ -103,11 +103,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "CursorSize") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "CursorSize") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);	
 
 							mag_zoomers_set_cursor (NULL, tattr_val, NULL);
@@ -115,11 +115,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "CursorZoomFactor") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "CursorZoomFactor") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);	
 
 							mag_zoomers_set_cursor (NULL, NULL, tattr_val);
@@ -127,11 +127,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "CursorScale") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "CursorScale") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);	
 
 							mag_zoomers_set_cursor_scale_on_off (tattr_val);
@@ -139,11 +139,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "CursorColor") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "CursorColor") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);	
 
 							mag_zoomers_set_cursor_color (tattr_val);
@@ -151,11 +151,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "cursor") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "cursor") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);	
 
 							mag_zoomers_set_cursor_on_off (tattr_val);
@@ -163,11 +163,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "crosswire") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "crosswire") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomers_set_crosswire_on_off (tattr_val);
@@ -175,11 +175,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "CrosswireSize") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "CrosswireSize") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomers_set_crosswire_size (tattr_val);
@@ -187,11 +187,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "CrosswireColor") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "CrosswireColor") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomers_set_crosswire_color (tattr_val);
@@ -199,11 +199,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "CrosswireClip") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "CrosswireClip") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomers_set_crosswire_clip (tattr_val);
@@ -229,8 +229,9 @@ mag_startElement (void           *ctx,
 			break;
 			
 		case MPS_OUT:
-			if (g_strcasecmp (name, "ZOOMER") == 0)
-			{					
+			if (g_strcasecmp ((gchar*)name, "ZOOMER") == 0)
+			{		
+				gboolean setZP = FALSE;			
 				/* create a new MAG_ZOOMER object*/
 				current_mag_zoomer = mag_zoomer_new();				
 				/* MAG_ZOOMER ATTRIBUTES*/
@@ -255,11 +256,11 @@ mag_startElement (void           *ctx,
 					invert="false"> 
 					</ZOOMER>
 					*/
-						if (g_strcasecmp (*attrs, "ID") == 0)
+						if (g_strcasecmp ((gchar*)*attrs, "ID") == 0)
 						{
 							++attrs;				
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val); /* trim the attr value*/
 
 							mag_zoomer_set_id (current_mag_zoomer, tattr_val);							
@@ -270,11 +271,11 @@ mag_startElement (void           *ctx,
 		
 						}
 						
-						else if (g_strcasecmp(*attrs, "visible") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "visible") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);	
 
 							mag_zoomer_set_params_visible (current_mag_zoomer, tattr_val);
@@ -283,11 +284,11 @@ mag_startElement (void           *ctx,
 							attr_val = NULL;						
 						}						
 						
-						else if (g_strcasecmp(*attrs, "ROILeft") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ROILeft") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ROI_left (current_mag_zoomer, tattr_val);
@@ -295,11 +296,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "ROITop") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ROITop") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ROI_top (current_mag_zoomer, tattr_val);
@@ -307,11 +308,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}
-						else if (g_strcasecmp(*attrs, "ROIWidth") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ROIWidth") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ROI_width (current_mag_zoomer, tattr_val);
@@ -319,11 +320,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}
-						else if (g_strcasecmp(*attrs, "ROIHeight") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ROIHeight") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ROI_height (current_mag_zoomer, tattr_val);
@@ -331,47 +332,50 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "ZPLeft") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ZPLeft") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ZP_extents_left (current_mag_zoomer, tattr_val);
+							setZP = TRUE;
 							
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "ZPTop") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ZPTop") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ZP_extents_top (current_mag_zoomer, tattr_val);
+							setZP = TRUE;
 							
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "ZPWidth") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ZPWidth") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ZP_extents_width (current_mag_zoomer, tattr_val);
+							setZP = TRUE;
 							
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "ZPHeight") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ZPHeight") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ZP_extents_height (current_mag_zoomer, tattr_val);
@@ -379,11 +383,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "BorderWidth") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "BorderWidth") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ZP_border_width (current_mag_zoomer, tattr_val);
@@ -391,11 +395,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;						
 						}						
-						else if (g_strcasecmp(*attrs, "BorderColor") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "BorderColor") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_ZP_border_color (current_mag_zoomer, tattr_val);
@@ -404,11 +408,11 @@ mag_startElement (void           *ctx,
 							attr_val = NULL;						
 						}						
 						
-						else if (g_strcasecmp(*attrs, "ZoomFactorX") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ZoomFactorX") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_zoom_factor (current_mag_zoomer, tattr_val, NULL);
@@ -417,11 +421,11 @@ mag_startElement (void           *ctx,
 							attr_val = NULL;												
 						}						
 						
-						else if (g_strcasecmp(*attrs, "ZoomFactorY") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "ZoomFactorY") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_zoom_factor (current_mag_zoomer, NULL, tattr_val);
@@ -430,11 +434,11 @@ mag_startElement (void           *ctx,
 							attr_val = NULL;												
 						}						
 
-						else if (g_strcasecmp (*attrs, "smoothing") == 0)
+						else if (g_strcasecmp ((gchar*)*attrs, "smoothing") == 0)
 						{
 							++attrs;
 							
-							attr_val  = g_strdup (*attrs);
+							attr_val  = g_strdup ((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_smoothing_alg (current_mag_zoomer, tattr_val);
@@ -443,11 +447,11 @@ mag_startElement (void           *ctx,
 							attr_val = NULL;												
 						}						
 						
-						else if (g_strcasecmp(*attrs, "invert") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "invert") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_invert (current_mag_zoomer, tattr_val);
@@ -455,11 +459,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "contrast") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "contrast") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_contrast (current_mag_zoomer, tattr_val);
@@ -467,11 +471,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "AlignmentX") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "AlignmentX") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_alignment (current_mag_zoomer, tattr_val, NULL);
@@ -479,11 +483,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "AlignmentY") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "AlignmentY") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_alignment (current_mag_zoomer, NULL, tattr_val);
@@ -491,11 +495,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "tracking") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "tracking") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_tracking (current_mag_zoomer, tattr_val);
@@ -503,11 +507,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "MouseTracking") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "MouseTracking") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_params_mouse_tracking (current_mag_zoomer, tattr_val);
@@ -515,11 +519,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}						
-						else if (g_strcasecmp(*attrs, "source") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "source") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_source (current_mag_zoomer, tattr_val);
@@ -527,11 +531,11 @@ mag_startElement (void           *ctx,
 							g_free (attr_val);
 							attr_val = NULL;												
 						}
-						else if (g_strcasecmp(*attrs, "target") == 0)
+						else if (g_strcasecmp((gchar*)*attrs, "target") == 0)
 						{
 							++attrs;
 
-							attr_val  = g_strdup(*attrs);
+							attr_val  = g_strdup((gchar*)*attrs);
 							tattr_val = g_strstrip (attr_val);
 
 							mag_zoomer_set_target (current_mag_zoomer, tattr_val);
@@ -556,7 +560,8 @@ mag_startElement (void           *ctx,
 					}
 					
 				}
-
+				if (setZP)
+				    mag_zoomer_set_ZP_extents (current_mag_zoomer);
 				current_state = MPS_ZOOMER;
 			}
 			
@@ -583,14 +588,14 @@ mag_endElement (void          *ctx,
 		
 		case MPS_IDLE:break;
 		case MPS_OUT:	
-			if (g_strcasecmp(name, "MAGOUT") == 0)
+			if (g_strcasecmp((gchar*)name, "MAGOUT") == 0)
 			{
 			    current_state = MPS_IDLE;
 			}
 		break;
 		
 		case MPS_ZOOMER: 
-			if (g_strcasecmp(name, "ZOOMER") == 0)
+			if (g_strcasecmp((gchar*)name, "ZOOMER") == 0)
 			{
 				/* give the MAG_ZOOMER to mag */
 				mag_add_zoomer (current_mag_zoomer);
@@ -623,7 +628,7 @@ mag_characters (void          *ctx,
 {
 	gchar*		tch;
 	/* make out own copy */
-	tch = g_strndup(ch, len);
+	tch = g_strndup((gchar*)ch, len);
 
 	switch (current_state)
 	{
