@@ -21,14 +21,13 @@
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
-#endif /* HAVE_CONFIG_H */
+#endif
+
 #include <glib.h>
 #include <string.h>
 #include <stdio.h>
 #include "sru-debug.h"
 
-#define SRU_DEBUG_CNT
-
 #ifdef SRU_DEBUG
 
 static GPtrArray *sru_debug_tags = NULL;
@@ -110,8 +109,7 @@ sru_debug_add_module_and_scopes (const gchar *module,
     for (i = 0; scopes_array[i]; i++)
     {
 	g_assert (scopes_array[i][0]);
-	g_ptr_array_add (sru_debug_tags, 
-			    g_strconcat (module, ":", scopes_array[i], NULL));
+	g_ptr_array_add (sru_debug_tags, g_strconcat (module, ":", scopes_array[i], NULL));
     }
     g_strfreev (scopes_array);
 }
@@ -125,36 +123,28 @@ sru_debug_log_all (const gchar *module,
     va_list args;
     gchar *message;
     gchar *scopes_real;
-#ifdef SRU_DEBUG_CNT
-    static long cnt = 0;
-#endif /* SRU_DEBUG_CNT */
 
     g_assert (module && module[0] && scopes && scopes[0]); 
     g_assert (sru_debug_file);
 
-    scopes_real = sru_debug_module_and_scopes_real_logged (module, scopes);
-    if (!scopes_real)
+    if (!(scopes_real = sru_debug_module_and_scopes_real_logged (module, scopes)))
 	return;
 
     va_start (args, format);
     message = g_strdup_vprintf (format, args);
-#ifdef SRU_DEBUG_CNT
-    fprintf (sru_debug_file, "\n%03ld %s\t%s\t%s", cnt++, module,
-						    scopes_real, message);
-#else /* SRU_DEBUG_CNT */
     fprintf (sru_debug_file, "\n%s\t%s\t%s", module, scopes_real, message);
-#endif /* SRU_DEBUG_CNT */
-
     g_free (message);
     g_free (scopes_real);
     va_end (args);
 }
 
-void
+gboolean
 sru_debug_init ()
 {
     sru_debug_file = stderr;
     sru_debug_tags = g_ptr_array_new ();
+
+    return TRUE;
 }
 
 void
